@@ -37,17 +37,23 @@ class Config(fixtures.Fixture):
         # reset is because cleanup works in reverse order of registered items,
         # and a reset must occur before unregistering options can occur.
         self.addCleanup(self._reset_default_config_files)
+        self.addCleanup(self._reset_default_config_dirs)
         self.addCleanup(self._unregister_config_opts)
         self.addCleanup(self.conf.reset)
         self._registered_config_opts = {}
 
-        # Grab an old copy of the default config files - if it exists - for
-        # subsequent cleanup.
+        # Grab an old copy of the default config files/dirs - if it exists -
+        # for subsequent cleanup.
         if hasattr(self.conf, 'default_config_files'):
             self._default_config_files = self.conf.default_config_files
         else:
             self._default_config_files = None
 
+        if hasattr(self.conf, 'default_config_dirs'):
+            self._default_config_dirs = self.conf.default_config_dirs
+        else:
+            self._default_config_dirs = None
+
     def config(self, **kw):
         """Override configuration values.
 
@@ -83,6 +89,17 @@ class Config(fixtures.Fixture):
             # being unset.
             self.conf.default_config_files = None
 
+    def _reset_default_config_dirs(self):
+        if not hasattr(self.conf, 'default_config_dirs'):
+            return
+
+        if self._default_config_dirs:
+            self.conf.default_config_dirs = self._default_config_dirs
+        else:
+            # Delete, because we could conceivably begin with the property
+            # being unset.
+            self.conf.default_config_dirs = None
+
     def register_opt(self, opt, group=None):
         """Register a single option for the test run.
 
@@ -181,6 +198,24 @@ class Config(fixtures.Fixture):
         self.conf.default_config_files = config_files
         self.conf.reload_config_files()
 
+    def set_config_dirs(self, config_dirs):
+        """Specify a list of config dirs to read.
+
+        This method allows you to predefine the list of configuration dirs
+        that are loaded by oslo_config. It will ensure that your tests do not
+        attempt to autodetect, and accidentally pick up config files from
+        locally installed services.
+        """
+        if not isinstance(config_dirs, list):
+            raise AttributeError("Please pass a list() to set_config_dirs()")
+
+        # Make sure the namespace exists for our tests.
+        if not self.conf._namespace:
+            self.conf([])
+
+        self.conf.default_config_dirs = config_dirs
+        self.conf.reload_config_files()
+
     def set_default(self, name, default, group=None):
         """Set a default value for an option.
 
