@@ -983,7 +983,7 @@ class IgnoreDoublesTestCase(base.BaseTestCase):
         ]
 
         slurped_opts = 0
-        for _, listing in generator._list_opts(None):
+        for _, listing in generator._list_opts(['namespace']):
             for _, opts in listing:
                 slurped_opts += len(opts)
         self.assertEqual(2, slurped_opts)
@@ -1200,8 +1200,10 @@ class RequiredOptionTestCase(base.BaseTestCase):
         fd, tmp_file = tempfile.mkstemp()
         with open(tmp_file, 'w+') as f:
             formatter = generator._OptFormatter(output_file=f)
-            generator._output_opts(formatter, 'alpha',
-                                   groups.pop('alpha'), True)
+            generator._output_opts(formatter,
+                                   'alpha',
+                                   groups.pop('alpha'),
+                                   minimal=True)
         expected = '''[alpha]
 
 #
@@ -1219,4 +1221,113 @@ bars = <None>
         self.assertEqual(expected, actual)
 
 
+class SummarizedOptionsTestCase(base.BaseTestCase):
+    """Validate 'summarize' config option.
+
+    The 'summarize' switch ensures only summaries of each configuration
+    option are output.
+    """
+
+    opts = [
+        cfg.StrOpt(
+            'foo',
+            default='fred',
+            help="""This is the summary line for a config option.
+
+I can provide a lot more detail here, but I may not want to bloat my
+config file. In this scenario, I can use the 'summarize' config option
+to ensure only a summary of the option is output to the config file.
+However, the Sphinx-generated documentation, hosted online, remains
+unchanged.
+
+Hopefully this works.
+"""),
+        cfg.StrOpt(
+            'bar',
+            required=True,
+            help="""This is a less carefully formatted configuration
+option, where the author has not broken their description into a brief
+summary line and larger description. Watch this person's commit
+messages!""")]
+
+    def test_summarized_option_order_single_ns(self):
+
+        config = [('namespace1', [('alpha', self.opts)])]
+        groups = generator._get_groups(config)
+
+        fd, tmp_file = tempfile.mkstemp()
+        with open(tmp_file, 'w+') as f:
+            formatter = generator._OptFormatter(output_file=f)
+            generator._output_opts(formatter,
+                                   'alpha',
+                                   groups.pop('alpha'),
+                                   summarize=True)
+        expected = '''[alpha]
+
+#
+# From namespace1
+#
+
+# This is the summary line for a config option. For more information,
+# refer to the documentation. (string value)
+#foo = fred
+
+# This is a less carefully formatted configuration
+# option, where the author has not broken their description into a
+# brief
+# summary line and larger description. Watch this person's commit
+# messages! (string value)
+#bar = <None>
+'''
+        with open(tmp_file, 'r') as f:
+            actual = f.read()
+        self.assertEqual(expected, actual)
+
+
+class AdvancedOptionsTestCase(base.BaseTestCase):
+
+    opts = [cfg.StrOpt('foo', help='foo option', default='fred'),
+            cfg.StrOpt('bar', help='bar option', advanced=True),
+            cfg.StrOpt('foo_bar', help='foobar'),
+            cfg.BoolOpt('bars', help='bars foo', default=True, advanced=True)]
+
+    def test_advanced_option_order_single_ns(self):
+
+        config = [("namespace1", [
+                   ("alpha", self.opts)])]
+        groups = generator._get_groups(config)
+
+        fd, tmp_file = tempfile.mkstemp()
+        with open(tmp_file, 'w+') as f:
+            formatter = generator._OptFormatter(output_file=f)
+            generator._output_opts(formatter, 'alpha', groups.pop('alpha'))
+        expected = '''[alpha]
+
+#
+# From namespace1
+#
+
+# foo option (string value)
+#foo = fred
+
+# foobar (string value)
+#foo_bar = <None>
+
+# bar option (string value)
+# Advanced Option: intended for advanced users and not used
+# by the majority of users, and might have a significant
+# effect on stability and/or performance.
+#bar = <None>
+
+# bars foo (boolean value)
+# Advanced Option: intended for advanced users and not used
+# by the majority of users, and might have a significant
+# effect on stability and/or performance.
+#bars = true
+'''
+        with open(tmp_file, 'r') as f:
+            actual = f.read()
+        self.assertEqual(expected, actual)
+
+
 GeneratorTestCase.generate_scenarios()
